==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "%s has published the calendar \"%s\"" : "%s opublikował/-a kalendarz \"%s\"",
    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Brak dostępu do kalendarza na zdalnym serwerze (HTTP {%s} error)",
    "Error connecting to remote server" : "Błąd podczas łączenia się z serwerem zdalnym",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Błąd żądania zasobu na zdalnym serwerze. Możliwe, że może to być związane z niedopasowaniem certyfikatu",
    "Error requesting resource on remote server" : "Błąd żądania zasobów na zdalnym serwerze",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Zasób",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracam do UTC",
    "Please create a calendar first." : "Proszę najpierw utworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "CalDAV address for clients" : "Adres CalDAV dla klientów",
    "Error saving WebCal-calendar" : "Błąd podczas zapisywania kalendarza WebCal",
    "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
    "EMail has been sent." : "E-mail został wysłany.",
    "There was an issue while sending your EMail." : "Wystąpił problem podczas wysyłania e-maila.",
    "group" : "grupa",
    "Details" : "Szczegóły",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Confirmed" : "Potwierdzone",
    "Tentative" : "Możliwe",
    "Cancelled" : "Przerwano",
    "Please add a title!" : "Proszę dodać tytuł!",
    "Please select a calendar!" : "Proszę wybrać kalendarz!",
    "The event ends before it starts!" : "Wydarzenie zakończyło się zanim zaczęło!",
    "Global" : "Ogólny",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Czy rozpocząć pracę przez importowanie kilku kalendarzy?",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "E Mail" : "e-mail",
    "Pop up" : "Powiadomienie wyskakujące",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "Successfully imported" : "Import zakończył się pomyślnie",
    "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
    "Partially imported, {n} failures" : "Import wykonany częściowo, {n} błędy/błędów",
    "Audio alarm" : "Alarm dźwiękowy",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem wydarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem wydarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu wydarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu wydarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
    "Title of the Event" : "Nazwa wydarzenia",
    "Starts" : "Zaczyna się",
    "Ends" : "Kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Location" : "Lokalizacja",
    "Description" : "Opis",
    "Event status" : "Status zdarzenia",
    "Visibility when sharing" : "Widoczność podczas współdzielenia",
    "Export" : "Eksportuj",
    "%s has published the calendar %s" : "%s opublikował/-a kalendarz %s",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz {boldstart}%s{boldend}.",
    "Click here to access it" : "Kliknij tutaj, aby uzyskać dostęp do niego",
    "Cheers!" : "Zdrówko!",
    "We wanted to inform you that %s has published the calendar %s." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz %s.",
    "Click on the link below to access it" : "Kliknij na link poniżej, aby uzyskać do niego dostęp",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Z powodu błędu w zewnętrznej bibliotece, kalendarz nie wspiera funkcji \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS, aby dowiedzieć się więcej.",
    "Share Calendar" : "Współdziel kalendarz",
    "Shared" : "Udostępniono",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "iCal link" : "Łącze iCal",
    "Download" : "Pobierz",
    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
    "can edit" : "może edytować",
    "Share link" : "Udostępnij link",
    "Public access" : "Dostęp publiczny",
    "Email link to person" : "Wyślij wiadomość do osoby",
    "Send" : "Wysłać",
    "New Calendar" : "Nowy kalendarz",
    "Name" : "Nazwa",
    "New Subscription" : "Nowa subskrypcja",
    "Go back" : "Wróć",
    "Go forward" : "Naprzód",
    "Calendar does not exist" : "Kalendarz nie istnieje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Być może link jest nieprawidłowy lub kalendarz przestał być współdzielony.",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Relative" : "Pokrewny",
    "Absolute" : "Całkowity",
    "Repeat" : "Powtarzaj",
    "times every" : "razy w każdy",
    "Add" : "Dodaj",
    "E-Mail address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
    "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie...",
    "times" : "razy",
    "Import Calendars" : "Importuj kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "File is empty" : "Plik jest pusty",
    "Import scheduled" : "Import został zaplanowany",
    "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
    "Embed" : "Osadź",
    "IFrame to integrate" : "Integracja z iframe",
    "Publish URL" : "Publikowanie URL",
    "Settings & import" : "Ustawienia i import",
    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
    "Show week numbers" : "Pokaż numery tygodni",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
    "Subscribe" : "Subskrybuj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "%s has published the calendar »%s«" : "%s opublikował kalendarz »%s«",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chcieliśmy poinformować, że %s opublikował kalendarz %s.",
    "Open »%s«" : "Otwórz »%s«",
    "Cheers!" : "Zdrówko!",
    "Recipient" : "Odbiorca",
    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Brak dostępu do kalendarza na zdalnym serwerze (HTTP {%s} error)",
    "Error connecting to remote server" : "Błąd podczas łączenia się z serwerem zdalnym",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Błąd żądania zasobu na zdalnym serwerze. Możliwe, że może to być związane z niedopasowaniem certyfikatu",
    "Error requesting resource on remote server" : "Błąd żądania zasobów na zdalnym serwerze",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Zasób",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracam do UTC",
    "Please create a calendar first." : "Proszę najpierw utworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "CalDAV address for clients" : "Adres CalDAV dla klientów",
    "Error saving WebCal-calendar" : "Błąd podczas zapisywania kalendarza WebCal",
    "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
    "Email has been sent." : "E-mail został wysłany.",
    "There was an issue while sending your email." : "Wystąpił problem podczas wysyłania e-maila.",
    "group" : "grupa",
    "Details" : "Szczegóły",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Confirmed" : "Potwierdzone",
    "Tentative" : "Możliwe",
    "Cancelled" : "Przerwano",
    "Please add a title." : "Dodaj tytuł.",
    "Please select a calendar." : "Wybierz kalendarz.",
    "The event can not end before it starts." : "Wydarzenie nie może kończyć się zanim się rozpocznie.",
    "Global" : "Ogólny",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Czy rozpocząć pracę przez importowanie kilku kalendarzy?",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "Successfully imported" : "Import zakończył się pomyślnie",
    "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
    "Partially imported, {n} failures" : "Import wykonany częściowo, {n} błędy/błędów",
    "Audio alarm" : "Alarm dźwiękowy",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem wydarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem wydarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu wydarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu wydarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
    "Title of the Event" : "Nazwa wydarzenia",
    "Starts" : "Zaczyna się",
    "Ends" : "Kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Location" : "Lokalizacja",
    "Description" : "Opis",
    "Event status" : "Status zdarzenia",
    "Visibility when sharing" : "Widoczność podczas współdzielenia",
    "Export" : "Eksportuj",
    "%s has published the calendar %s" : "%s opublikował/-a kalendarz %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz {boldstart}%s{boldend}.",
    "Click here to access it" : "Kliknij tutaj, aby uzyskać dostęp do niego",
    "We wanted to inform you that %s has published the calendar %s." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz %s.",
    "Click on the link below to access it" : "Kliknij na link poniżej, aby uzyskać do niego dostęp",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS, aby dowiedzieć się więcej.",
    "Share Calendar" : "Współdziel kalendarz",
    "Shared" : "Udostępniono",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "iCal link" : "Łącze iCal",
    "Download" : "Pobierz",
    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
    "can edit" : "może edytować",
    "Share link" : "Udostępnij link",
    "Public access" : "Dostęp publiczny",
    "Email link to person" : "Wyślij wiadomość do osoby",
    "Send" : "Wysłać",
    "New Calendar" : "Nowy kalendarz",
    "Name" : "Nazwa",
    "New Subscription" : "Nowa subskrypcja",
    "Go back" : "Wróć",
    "Go forward" : "Naprzód",
    "Calendar does not exist" : "Kalendarz nie istnieje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Być może link jest nieprawidłowy lub kalendarz przestał być współdzielony.",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Relative" : "Pokrewny",
    "Absolute" : "Całkowity",
    "Repeat" : "Powtarzaj",
    "times every" : "razy w każdy",
    "Add" : "Dodaj",
    "Email address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
    "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie...",
    "times" : "razy",
    "Import Calendars" : "Importuj kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "File is empty" : "Plik jest pusty",
    "Import scheduled" : "Import został zaplanowany",
    "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
    "Embed" : "Osadź",
    "Iframe to integrate" : "Iframe do osadzenia",
    "Publish URL" : "Publikowanie URL",
    "Settings & import" : "Ustawienia i import",
    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
    "Show week numbers" : "Pokaż numery tygodni",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
    "Subscribe" : "Subskrybuj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
